@@ -1,5 +1,7 @@
 #pragma once
 
+#include <pcap.h>
+
 #include <filesystem>
 #include <istream>
 #include <tuple>
@@ -15,7 +17,8 @@ namespace caracal::Prober {
 /// probes.
 using Iterator = std::function<bool(Probe&)>;
 
-using ProbingStatistics = std::tuple<Statistics::Prober, Statistics::Sniffer>;
+using ProbingStatistics =
+    std::tuple<Statistics::Prober, Statistics::Sniffer, pcap_stat>;
 
 /// Send probes from a function yielding probes.
 ProbingStatistics probe(const Config& config, Iterator& it);
