@@ -1,5 +1,4 @@
 import logging
-from ipaddress import ip_address
 
 from pycaracal import Probe, experimental, protocols, set_log_level, utilities
 
@@ -9,9 +8,9 @@ def test_prober():
         utilities.get_default_interface(), 100, 1024 * 1024, 1, True
     )
     probes = [
-        Probe(ip_address("8.8.4.4"), 24000, 33434, 32, protocols.L4.ICMP),
-        Probe(ip_address("8.8.4.4"), 24000, 33434, 32, protocols.L4.UDP),
+        Probe("8.8.4.4", 24000, 33434, 32, protocols.L4.ICMP),
+        Probe("8.8.4.4", 24000, 33434, 32, protocols.L4.UDP),
     ]
     set_log_level(logging.DEBUG)
-    replies = prober.probe(probes, 0)
+    replies = prober.probe(probes, 1000)
     assert isinstance(replies, list)
