@@ -17,8 +17,7 @@
 #include <caracal/protocols.hpp>
 #include <caracal/timestamp.hpp>
 #include <caracal/utilities.hpp>
-#include <catch2/benchmark/catch_benchmark.hpp>
-#include <catch2/catch_test_macros.hpp>
+#include <catch2/catch.hpp>
 
 using caracal::Packet;
 using caracal::Builder::transport_checksum;
