@@ -1,7 +1,7 @@
 #include <arpa/inet.h>
 
 #include <caracal/checked.hpp>
-#include <catch2/catch_test_macros.hpp>
+#include <catch2/catch.hpp>
 #include <stdexcept>
 
 using caracal::Checked::hton;
