@@ -1,8 +1,8 @@
 #include <caracal/rate_limiter.hpp>
-#include <catch2/catch_test_macros.hpp>
+#include <catch2/catch.hpp>
 #include <chrono>
 
-#include "environment.hpp"
+#include "./environment.hpp"
 
 using caracal::RateLimiter;
 using std::chrono::duration_cast;
